@@ -1,3 +1,5 @@
+from __future__ import annotations
+
 import functools
 import itertools
 from collections import defaultdict
@@ -71,6 +73,20 @@ class Scale(NoteSet):
             for i in range(len(self))
         )
 
+    def parallel(self, parallel_name: str | None = None) -> Scale:
+        """same root, convert major to minor and vice versa"""
+        if parallel_name is None:
+            parallel_name = {'major': 'minor', 'minor': 'major'}[self.name]
+        return Scale.from_name(self.root, parallel_name)
+
+    def relative(self, relative_name: str | None = None) -> Scale:
+        """same set of notes, changes root, convert major to minor and vice versa"""
+        if relative_name is None:
+            relative_name = {'major': 'minor', 'minor': 'major'}[self.name]
+        for note, name in self.note_scales.items():
+            if name == relative_name:
+                return Scale.from_name(note, name)
+
     def to_piano_image(self):
         return Piano(scale=self)._repr_svg_()
 
@@ -87,7 +103,7 @@ class Scale(NoteSet):
         chords_hover = ''
         return f'''
         <div class='{' '.join(self.html_classes)}' {chords_hover}>
-        <a href='{self.root.name}'><span class='card_header'><h3>{self.root.name} {self.name}</h3></span></a>
+        <a href='{self.root.name}'><span class='card_header'><h3>{self.root.name} {self.name} | C {self.note_scales[Note('C')]}</h3></span></a>
         {self.to_piano_image()}
         </div>
         '''
@@ -200,16 +216,3 @@ def print_neighbors(s: Scale):
 #     _ = scale.to_piano_image(as_base64=True)
 #     for neighbor in itertools.chain.from_iterable(neighbors(scale).values()):
 #         _ = neighbor.to_piano_image(as_base64=True)
-
-
-def parallel(s: Scale):
-    """same root, convert major to minor and vice versa"""
-    return Scale.from_name(s.root, {'major': 'minor', 'minor': 'major'}[s.name])
-
-
-def relative(s: Scale):
-    """same set of notes, changes root, convert major to minor and vice versa"""
-    relative_name = {'major': 'minor', 'minor': 'major'}[s.name]
-    for note, name in s.note_scales.items():
-        if name == relative_name:
-            return Scale.from_name(note, name)
